@@ -27,6 +27,7 @@ def main():
     parser_lastevent = subparsers.add_parser('lastevent', help='Display last event log reported by Cognicept agent')
     parser_update = subparsers.add_parser('update', help='Update Cognicept tools')
     parser_restart = subparsers.add_parser('restart', help='Restart Cognicept agents')
+    parser_start = subparsers.add_parser('start', help='Start Cognicept agents')
     parser_stop = subparsers.add_parser('stop', help='Stops Cognicept agents')
     parser_orbitty = subparsers.add_parser('orbitty', help='Run Orbitty')
     parser_record = subparsers.add_parser('record', help='Manages rosbag recording')
@@ -50,6 +51,9 @@ def main():
     parser_restart.set_defaults(func=agent_lifetime.restart)
     parser_restart.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 
+    parser_start.set_defaults(func=agent_lifetime.run)
+    parser_start.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
+
     parser_stop.set_defaults(func=agent_lifetime.remove_agents)
     parser_stop.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 
