@@ -47,7 +47,7 @@ class Pusher:
 
     def __init__(self):
         self.s3_client = boto3.client('s3')
-        self.bucket_name = 'marv-scanroot'
+        self.bucket_name = 'cognicept-bagfiles'
 
     def push(self, args):
         """
@@ -142,11 +142,7 @@ class Pusher:
         payload = {
             "robot_id": args.config.get_field("ROBOT_CODE"),
             "bagfile_name": ntpath.basename(bag_file_path),
-            "bagfile_url": ("https://s3-" +
-                            boto3.session.Session().region_name +
-                            ".amazonaws.com/" +
-                            self.bucket_name + "/" +
-                            ntpath.basename(bag_file_path)),
+            "bagfile_url": ntpath.basename(bag_file_path),
             "bagfile_size": str(os.path.getsize(bag_file_path)),
             "uploaded_at": datetime.datetime.now().isoformat()
         }
